Interface: ChartData | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ChartData<TType, TData, TLabel>

TData represents the data point type. If unspecified, a default is provided based on the chart type. TLabel represents the label type

## # Type parameters

Name | Type
--- | ---
`TType` | extends `ChartType` = `ChartType`
`TData` | `DefaultDataPoint`<`TType`>
`TLabel` | `unknown`

## # Properties

### # datasets

• datasets: `ChartDataset`<`TType`, `TData`>[]

#### # Defined in

index.esm.d.ts:3684
(opens new window)

### # labels

• `Optional` labels: `TLabel`[]

#### # Defined in

index.esm.d.ts:3683
(opens new window)